@@ -1,5 +1,5 @@
-/* Arg_parser - POSIX/GNU command line argument parser. (C++ version)
-   Copyright (C) 2006-2022 Antonio Diaz Diaz.
+/* Arg_parser - POSIX/GNU command-line argument parser. (C++ version)
+   Copyright (C) 2006-2024 Antonio Diaz Diaz.
 
    This program is free software: you have unlimited permission to
    copy, distribute, and modify it.
@@ -10,9 +10,9 @@
 */
 /*
    Exit status: 0 for a normal exit, 1 for environmental problems
-   (file not found, invalid flags, I/O errors, etc), 2 to indicate a
-   corrupt or invalid input file, 3 for an internal consistency error
-   (e.g., bug) which caused arg_parser to panic.
+   (file not found, invalid command-line options, I/O errors, etc), 2 to
+   indicate a corrupt or invalid input file, 3 for an internal consistency
+   error (e.g., bug) which caused arg_parser to panic.
 */
 
 #include <climits>
@@ -28,15 +28,15 @@
 namespace {
 
 const char * const program_name = "arg_parser";
-const char * const program_year = "2022";
+const char * const program_year = "2024";
 const char * invocation_name = program_name;		// default value
 
 
 void show_help( const bool verbose )
   {
-  std::printf( "Arg_parser - POSIX/GNU command line argument parser. (C++ version)\n"
+  std::printf( "Arg_parser - POSIX/GNU command-line argument parser. (C++ version)\n"
                "\nArg_parser is an argument parser that follows POSIX and GNU conventions for\n"
-               "command line arguments. There exist C++ and C versions of Arg_parser. The\n"
+               "command-line arguments. There exist C++ and C versions of Arg_parser. The\n"
                "C++ version is implemented as a C++ class, while the C version is\n"
                "implemented as a single struct plus associated functions. Both are simpler,\n"
                "easier to use, and safer than 'getopt_long'.\n"
@@ -146,7 +146,7 @@ int main( const int argc, const char * const argv[] )
       case 256: break;				// example, do nothing
       case INT_MIN: break;			// example, do nothing
       case INT_MAX: break;			// example, do nothing
-      default : internal_error( "uncaught option." );
+      default: internal_error( "uncaught option." );
       }
     } // end process options
 
